@@ -1,7 +1,7 @@
-from .pre_utils import LayerLoader, get_logger, load_basic_debug_mode
+from .pre_utils import DebugMode, LayerLoader, get_logger
 
 __app_name = LayerLoader._self_app_name = LayerLoader._app_name = "rya"
 LayerLoader.logger = get_logger()
-load_basic_debug_mode(__app_name)
+DebugMode(__app_name).load(reload=True)
 
 __all__ = []
